@@ -15,13 +15,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = '0.1.3'
-
-import logging
+__version__ = '0.2.8'
 
 try:
     import settings_local as settings
-    logging.debug("Using settings_local.py as settings")
 except ImportError, ie:
     try:
         import settings
@@ -29,6 +26,6 @@ except ImportError, ie:
         class settings(object):
             DEBUG = True
             PROFILING = False
-            COOKIE_SECRET = "29NbhyfgaA092ZkjMbNvCx06789jdA8iIlLqz7d1D9c8"
-        
-settings = settings
\ No newline at end of file
+            COOKIE_SECRET = ""
+
+settings = settings
